

GRANT SELECT ON TABLE suchtabelle_#{jahr} TO #{role};
GRANT SELECT ON TABLE suchtabelle_en_#{jahr} TO #{role};
GRANT SELECT ON TABLE betriebe_#{jahr} TO #{role};
GRANT SELECT ON TABLE betriebe_gis_#{jahr} TO #{role};



