-- SQL e-PRTR Entfernung von Betrieben, die weder Freisetzungen noch
-- Verbringungen haben

-- (c) ENDA GmbH & Co. KG, 2011
-- Dieses Skript steht unter GNU Gpl. V3

-- Rev. 0, 2011-03-21 16:00, mlt: Umstellung auf Nutzung von k_laender_fuer_aktualisierung für 2007, 2008 und 2009


-- SEQUENZEN AUFFRISCHEN --

select risa_adjust_sequences();
select model.risa_adjust_sequences();


-- GIS-Easy-Tabellen säubern:


-- Einträge derjenigen Betriebe löschen, die weder Freisetzungen noch Verbringungen haben:
delete from suchtabelle_#{jahr} st
using betriebe_#{jahr} b
where st.betrieb_id  = b.id
  and b.p_betrieb_id in
(
select distinct b2.id
from p_betrieb b2
  left join p_freis f
    on b2.id = f.p_betrieb_id
  left join p_vabw vaw
    on b2.id = vaw.p_betrieb_id
  left join p_vabf vaf
    on b2.id = vaf.p_betrieb_id
where f.p_betrieb_id is null
  and vaw.p_betrieb_id is null
  and vaf.p_betrieb_id is null
);

delete from betriebe_#{jahr} b
where b.p_betrieb_id in
(
select distinct b2.id
from p_betrieb b2
  left join p_freis f
    on b2.id = f.p_betrieb_id
  left join p_vabw vaw
    on b2.id = vaw.p_betrieb_id
  left join p_vabf vaf
    on b2.id = vaf.p_betrieb_id
where f.p_betrieb_id is null
  and vaw.p_betrieb_id is null
  and vaf.p_betrieb_id is null
);

delete from betriebe_gis_#{jahr} bg
where bg.p_betrieb_id in
(
select distinct b2.id
from p_betrieb b2
  left join p_freis f
    on b2.id = f.p_betrieb_id
  left join p_vabw vaw
    on b2.id = vaw.p_betrieb_id
  left join p_vabf vaf
    on b2.id = vaf.p_betrieb_id
where f.p_betrieb_id is null
  and vaw.p_betrieb_id is null
  and vaf.p_betrieb_id is null
);
